[FFmpeg-devel] [PATCH 4/6] Rename ff_eval_free() to av_free_expr().

Stefano Sabatini stefano.sabatini-lala
Sat Apr 10 13:50:31 CEST 2010


---
 libavcodec/eval.c        |   18 +++++++++---------
 libavcodec/eval.h        |    5 +++--
 libavcodec/ratecontrol.c |    2 +-
 3 files changed, 13 insertions(+), 12 deletions(-)

diff --git a/libavcodec/eval.c b/libavcodec/eval.c
index ce1f69a..dad689b 100644
--- a/libavcodec/eval.c
+++ b/libavcodec/eval.c
@@ -173,10 +173,10 @@ static double eval_expr(Parser * p, AVExpr * e) {
 
 static AVExpr * parse_expr(Parser *p);
 
-void ff_eval_free(AVExpr * e) {
+void av_free_expr(AVExpr * e) {
     if (!e) return;
-    ff_eval_free(e->param[0]);
-    ff_eval_free(e->param[1]);
+    av_free_expr(e->param[0]);
+    av_free_expr(e->param[1]);
     av_freep(&e);
 }
 
@@ -211,7 +211,7 @@ static AVExpr * parse_primary(Parser *p) {
     if(p->s==NULL){
         *p->error = "undefined constant or missing (";
         p->s= next;
-        ff_eval_free(d);
+        av_free_expr(d);
         return NULL;
     }
     p->s++; // "("
@@ -220,7 +220,7 @@ static AVExpr * parse_primary(Parser *p) {
         d = parse_expr(p);
         if(p->s[0] != ')'){
             *p->error = "missing )";
-            ff_eval_free(d);
+            av_free_expr(d);
             return NULL;
         }
         p->s++; // ")"
@@ -233,7 +233,7 @@ static AVExpr * parse_primary(Parser *p) {
     }
     if(p->s[0] != ')'){
         *p->error = "missing )";
-        ff_eval_free(d);
+        av_free_expr(d);
         return NULL;
     }
     p->s++; // ")"
@@ -282,7 +282,7 @@ static AVExpr * parse_primary(Parser *p) {
         }
 
         *p->error = "unknown function";
-        ff_eval_free(d);
+        av_free_expr(d);
         return NULL;
     }
 
@@ -404,7 +404,7 @@ AVExpr * ff_parse(const char *s, const char * const *const_name,
 
     e = parse_expr(&p);
     if (!verify_expr(e)) {
-        ff_eval_free(e);
+        av_free_expr(e);
         e = NULL;
     }
 end:
@@ -428,7 +428,7 @@ double ff_eval2(const char *s, const double *const_value, const char * const *co
     double d;
     if (!e) return NAN;
     d = ff_parse_eval(e, const_value, opaque);
-    ff_eval_free(e);
+    av_free_expr(e);
     return d;
 }
 
diff --git a/libavcodec/ratecontrol.c b/libavcodec/ratecontrol.c
index 02a235c..51da514 100644
--- a/libavcodec/ratecontrol.c
+++ b/libavcodec/ratecontrol.c
@@ -255,7 +255,7 @@ void ff_rate_control_uninit(MpegEncContext *s)
     RateControlContext *rcc= &s->rc_context;
     emms_c();
 
-    ff_eval_free(rcc->rc_eq_eval);
+    av_free_expr(rcc->rc_eq_eval);
     av_freep(&rcc->entry);
 
 #if CONFIG_LIBXVID
diff --git a/libavcodec/eval.h b/libavcodec/eval.h
index e5135f0..4b5ac3a 100644
--- a/libavcodec/eval.h
+++ b/libavcodec/eval.h
@@ -58,7 +58,7 @@ double ff_eval2(const char *s, const double *const_value, const char * const *co
  * @param func1_name NULL terminated array of zero terminated strings of func1 identifers
  * @param func2_name NULL terminated array of zero terminated strings of func2 identifers
  * @param error pointer to a char* which is set to an error message if something goes wrong
  * @return AVExpr which must be freed with ff_eval_free by the user when it is not needed anymore
  *         NULL if anything went wrong
  */
 AVExpr * ff_parse(const char *s, const char * const *const_name,
@@ -72,7 +72,8 @@ AVExpr * ff_parse(const char *s, const char * const *const_name,
  * @return the value of the expression
  */
 double ff_parse_eval(AVExpr * e, const double *const_value, void *opaque);
-void ff_eval_free(AVExpr * e);
+
+void av_free_expr(AVExpr *e);
 
 /**
  * Parses the string in numstr and returns its value as a double. If
@@ -58,7 +58,7 @@ double ff_eval2(const char *s, const double *const_value, const char * const *co
  * @param func2_name NULL terminated array of zero terminated strings of func2 identifers
  * @param error pointer to a char* which is set to an error message if something goes wrong
- * @return AVExpr which must be freed with ff_eval_free by the user when it is not needed anymore
+ * @return AVExpr which must be freed with av_free_expr() by the user when it is not needed anymore
  *         NULL if anything went wrong
  */
-- 
1.7.0




More information about the ffmpeg-devel mailing list